#ifndef FL_LOGBOOK_H
#define FL_LOGBOOK_H

#include "lgbook.h"
#include "logsupport.h"

extern void start_logbook();
extern void close_logbook();

#endif
